@@ -19,9 +19,10 @@ except ImportError:
 
 class BlueDo(Gtk.Application):
     project_name = 'bluedo'
-    project_version = .49
+    project_version = .52
     config_path = appdirs.user_config_dir(project_name) + '/' + project_name + '.ini'
     config_section = 'CONFIG'
+    run_path = os.path.dirname(os.path.realpath(__file__))
 
     builder = None
     enabled = False
@@ -75,7 +76,7 @@ class BlueDo(Gtk.Application):
 
         # Load widgets from glade file
         self.builder = Gtk.Builder()
-        self.builder.add_from_file(os.path.dirname(os.path.realpath(__file__)) + "/window.glade")
+        self.builder.add_from_file(self.run_path + "/window.glade")
 
         self.button_enabled = self.builder.get_object("button_enabled")
         self.combo_device = self.builder.get_object("combo_device")
@@ -96,10 +97,13 @@ class BlueDo(Gtk.Application):
         self.menuitem_enable = self.builder.get_object("menuitem_enable")
         self.label_info = self.builder.get_object("label_info")
         self.levelSignal = self.builder.get_object("levelSignal")
+        self.instructions_viewport = self.builder.get_object("instructions_viewport")
 
         self.link_bluetoothsettings = self.builder.get_object("link_bluetoothsettings")
         self.link_bluetoothsettings.set_label("Bluetooth settings")
 
+        self.show_animation()
+
         # Load config
         self.load_config()
 
@@ -119,7 +123,7 @@ class BlueDo(Gtk.Application):
         self.entry_here.set_text("%s" % self.here_command)
 
         # Icon
-        self.icon_path = os.path.dirname(os.path.realpath(__file__)) + "/bluedo.png"
+        self.icon_path = self.run_path + "/bluedo.png"
 
         self.window = self.builder.get_object("main_window")
         try:
@@ -163,7 +167,7 @@ class BlueDo(Gtk.Application):
 
         # Tray icon
         indicator = AppIndicator3.Indicator.new("customtray",
-            os.path.dirname(os.path.realpath(__file__)) + "/bluedo_indicator.png",
+            self.run_path + "/bluedo_indicator.png",
             AppIndicator3.IndicatorCategory.APPLICATION_STATUS)
         indicator.set_status(AppIndicator3.IndicatorStatus.ACTIVE)
         indicator.set_menu(self.dropdown_menu)
@@ -185,6 +189,26 @@ class BlueDo(Gtk.Application):
 
         Gtk.main_quit()
 
+    def show_animation(self):
+        ''' Show a demo animation for 30 sec, then switch to static image '''
+
+        path_animation = self.run_path + "lock_animation.gif"
+        pixbufanim = GdkPixbuf.PixbufAnimation.new_from_file(path_animation)
+        self.demo_image = Gtk.Image()
+        self.demo_image.set_from_animation(pixbufanim)
+        self.instructions_viewport.add(self.demo_image)
+        self.demo_image.show()
+        GLib.timeout_add(30000, self.stop_animation)
+
+    def stop_animation(self):
+        ''' Switch demo animation to static image '''
+
+        path_picture = self.run_path + "unlocked.png"
+        pixbuf = GdkPixbuf.PixbufAnimation.new_from_file(path_picture)
+        self.demo_image.set_from_animation(pixbuf)
+        self.instructions_viewport.add(self.demo_image)
+
+
 #
 # Widgets
 #
